@@ -24,6 +24,7 @@ List of all possible formatting presets and their values.
 Current version of program.
 
 	"""
+	OUTPUT_FORMAT = ".png"
 	def __init__(self):
 		"""
 
@@ -39,3 +40,5 @@ Reads configuration file and
 			sys.exit(1)
 		self.DEFAULT_PRESET = config["default-preset"]
 		self.PRESETS = config["presets"]
+		if config["version"] == "0.9.8":
+			self.OUTPUT_FORMAT = config["image-out"]
